@@ -16,7 +16,6 @@
 #include <QRegExp> // for the word ranges
 #endif
 #include <QRegularExpression>
-#include <QStringList>
 #include <QVector>
 
 //
@@ -40,103 +39,90 @@ QString KStringHandler::capwords(const QString &text)
 QStringList KStringHandler::capwords(const QStringList &list)
 {
     QStringList tmp = list;
-    for (QStringList::Iterator it = tmp.begin(); it != tmp.end(); ++it) {
-        *it = (*it)[0].toUpper() + (*it).midRef(1);
+    for (auto &str : tmp) {
+        str[0] = str.at(0).toUpper();
     }
     return tmp;
 }
 
-QString KStringHandler::lsqueeze(const QString &str, int maxlen)
+QString KStringHandler::lsqueeze(const QString &str, const int maxlen)
 {
     if (str.length() > maxlen) {
-        int part = maxlen - 3;
-        return QLatin1String("...") + str.rightRef(part);
+        const int part = maxlen - 3;
+        return QLatin1String("...") + QStringView(str).right(part);
     } else {
         return str;
     }
 }
 
-QString KStringHandler::csqueeze(const QString &str, int maxlen)
+QString KStringHandler::csqueeze(const QString &str, const int maxlen)
 {
     if (str.length() > maxlen && maxlen > 3) {
         const int part = (maxlen - 3) / 2;
-        return str.leftRef(part) + QLatin1String("...") + str.rightRef(part);
+        const QStringView strView{str};
+        return strView.left(part) + QLatin1String("...") + strView.right(part);
     } else {
         return str;
     }
 }
 
-QString KStringHandler::rsqueeze(const QString &str, int maxlen)
+QString KStringHandler::rsqueeze(const QString &str, const int maxlen)
 {
     if (str.length() > maxlen) {
-        int part = maxlen - 3;
-        return str.leftRef(part) + QLatin1String("...");
+        const int part = maxlen - 3;
+        return QStringView(str).left(part) + QLatin1String("...");
     } else {
         return str;
     }
 }
 
+QStringList KStringHandler::perlSplit(const QStringView sep, const QStringView str, int max)
+{
+    const bool ignoreMax = max == 0;
+
+    const int sepLength = sep.size();
+
+    QStringList list;
+    int searchStart = 0;
+    int sepIndex = str.indexOf(sep, searchStart);
+
+    while (sepIndex != -1 && (ignoreMax || list.count() < max - 1)) {
+        const auto chunk = str.mid(searchStart, sepIndex - searchStart);
+        if (!chunk.isEmpty()) {
+            list.append(chunk.toString());
+        }
+
+        searchStart = sepIndex + sepLength;
+        sepIndex = str.indexOf(sep, searchStart);
+    }
+
+    const auto lastChunk = str.mid(searchStart, str.length() - searchStart);
+    if (!lastChunk.isEmpty()) {
+        list.append(lastChunk.toString());
+    }
+
+    return list;
+}
+
 QStringList KStringHandler::perlSplit(const QString &sep, const QString &s, int max)
 {
-    bool ignoreMax = 0 == max;
-
-    QStringList l;
-
-    int searchStart = 0;
-
-    int tokenStart = s.indexOf(sep, searchStart);
-
-    while (-1 != tokenStart && (ignoreMax || l.count() < max - 1)) {
-        if (!s.midRef(searchStart, tokenStart - searchStart).isEmpty()) {
-            l << s.mid(searchStart, tokenStart - searchStart);
-        }
-
-        searchStart = tokenStart + sep.length();
-        tokenStart = s.indexOf(sep, searchStart);
-    }
-
-    if (!s.midRef(searchStart, s.length() - searchStart).isEmpty()) {
-        l << s.mid(searchStart, s.length() - searchStart);
-    }
-
-    return l;
+    return perlSplit(QStringView(sep), QStringView(s), max);
 }
 
-QStringList KStringHandler::perlSplit(const QChar &sep, const QString &s, int max)
+QStringList KStringHandler::perlSplit(const QChar &sep, const QString &str, int max)
 {
-    bool ignoreMax = 0 == max;
-
-    QStringList l;
-
-    int searchStart = 0;
-
-    int tokenStart = s.indexOf(sep, searchStart);
-
-    while (-1 != tokenStart && (ignoreMax || l.count() < max - 1)) {
-        if (!s.midRef(searchStart, tokenStart - searchStart).isEmpty()) {
-            l << s.mid(searchStart, tokenStart - searchStart);
-        }
-
-        searchStart = tokenStart + 1;
-        tokenStart = s.indexOf(sep, searchStart);
-    }
-
-    if (!s.midRef(searchStart, s.length() - searchStart).isEmpty()) {
-        l << s.mid(searchStart, s.length() - searchStart);
-    }
-
-    return l;
+    return perlSplit(QStringView(&sep, 1), QStringView(str), max);
 }
 
 #if KCOREADDONS_BUILD_DEPRECATED_SINCE(5, 67)
-QStringList KStringHandler::perlSplit(const QRegExp &sep, const QString &s, int max)
+QStringList KStringHandler::perlSplit(const QRegExp &sep, const QString &s, const int max)
 {
     // nothing to split
     if (s.isEmpty()) {
         return QStringList();
     }
 
-    bool ignoreMax = 0 == max;
+    const bool ignoreMax = 0 == max;
 
     QStringList l;
 
@@ -162,34 +148,40 @@ QStringList KStringHandler::perlSplit(const QRegExp &sep, const QString &s, int
 }
 #endif
 
-QStringList KStringHandler::perlSplit(const QRegularExpression &sep, const QString &s, int max)
+QStringList KStringHandler::perlSplit(const QRegularExpression &sep, const QString &str, int max)
 {
     // nothing to split
-    if (s.isEmpty()) {
+    if (str.isEmpty()) {
         return QStringList();
     }
 
-    bool ignoreMax = max == 0;
+    const bool ignoreMax = max == 0;
 
     QStringList list;
 
     int start = 0;
-    QRegularExpressionMatchIterator iter = sep.globalMatch(s);
+
+    const QStringView strView(str);
+
+    QRegularExpression separator(sep);
+    separator.setPatternOptions(QRegularExpression::UseUnicodePropertiesOption);
+
+    QRegularExpressionMatchIterator iter = separator.globalMatch(strView);
     QRegularExpressionMatch match;
-    QString chunk;
     while (iter.hasNext() && (ignoreMax || list.count() < max - 1)) {
         match = iter.next();
-        chunk = s.mid(start, match.capturedStart() - start);
+        const QStringView chunk = strView.mid(start, match.capturedStart() - start);
         if (!chunk.isEmpty()) {
-            list.append(chunk);
+            list.append(chunk.toString());
         }
+
         start = match.capturedEnd();
     }
 
     // catch the remainder
-    chunk = s.mid(start, s.size() - start);
-    if (!chunk.isEmpty()) {
-        list.append(chunk);
+    const QStringView lastChunk = strView.mid(start, strView.size() - start);
+    if (!lastChunk.isEmpty()) {
+        list.append(lastChunk.toString());
     }
 
     return list;
@@ -198,29 +190,31 @@ QStringList KStringHandler::perlSplit(const QRegularExpression &sep, const QStri
 QString KStringHandler::tagUrls(const QString &text)
 {
     QString richText(text);
-    const QRegularExpression urlEx(QStringLiteral("(www\\.(?!\\.)|(fish|ftp|http|https)://[\\d\\w\\./,:_~\\?=&;#@\\-\\+\\%\\$\\(\\)]+)"));
-    // the reference \1 is going to be replaced by the matched url
-    const QLatin1String regexBackRef(QLatin1String("\\1"));
-    const QString anchor = QLatin1String("<a href=\"") + regexBackRef + QLatin1String("\">") + regexBackRef + QLatin1String("</a>");
-    richText.replace(urlEx, anchor);
+
+    static const QRegularExpression urlEx(QStringLiteral(R"((www\.(?!\.)|(fish|ftp|http|https)://[\d\w./,:_~?=&;#@\-+%$()]+))"),
+                                          QRegularExpression::UseUnicodePropertiesOption);
+    // The reference \1 is going to be replaced by the matched url
+    richText.replace(urlEx, QStringLiteral("<a href=\"\\1\">\\1</a>"));
     return richText;
 }
 
 QString KStringHandler::obscure(const QString &str)
 {
     QString result;
-    const QChar *unicode = str.unicode();
-    for (int i = 0; i < str.length(); ++i)
+    for (const QChar ch : str) {
         // yes, no typo. can't encode ' ' or '!' because
         // they're the unicode BOM. stupid scrambling. stupid.
-        result += (unicode[i].unicode() <= 0x21) ? unicode[i] : QChar(0x1001F - unicode[i].unicode());
+        const ushort uc = ch.unicode();
+        result += (uc <= 0x21) ? ch : QChar(0x1001F - uc);
+    }
 
     return result;
 }
 
 bool KStringHandler::isUtf8(const char *buf)
 {
-    int i, n;
+    int i;
+    int n;
     unsigned char c;
     bool gotone = false;
 
@@ -330,12 +324,15 @@ QString KStringHandler::preProcessWrap(const QString &text)
 
     for (int i = 0; i < text.length(); i++) {
         const QChar c = text[i];
-        bool openingParens = (c == QLatin1Char('(') || c == QLatin1Char('{') || c == QLatin1Char('['));
-        bool singleQuote = (c == QLatin1Char('\''));
-        bool closingParens = (c == QLatin1Char(')') || c == QLatin1Char('}') || c == QLatin1Char(']'));
-        bool breakAfter = (closingParens || c.isPunct() || c.isSymbol());
-        bool nextIsSpace = (i == (text.length() - 1) || text[i + 1].isSpace());
-        bool prevIsSpace = (i == 0 || text[i - 1].isSpace() || result[result.length() - 1] == zwsp);
+        const bool openingParens = (c == QLatin1Char('(') || c == QLatin1Char('{') || c == QLatin1Char('['));
+        const bool singleQuote = (c == QLatin1Char('\''));
+        const bool closingParens = (c == QLatin1Char(')') || c == QLatin1Char('}') || c == QLatin1Char(']'));
+        const bool breakAfter = (closingParens || c.isPunct() || c.isSymbol());
+        const bool isLastChar = i == (text.length() - 1);
+        const bool isLower = c.isLower();
+        const bool nextIsUpper = !isLastChar && text[i + 1].isUpper(); // false by default
+        const bool nextIsSpace = isLastChar || text[i + 1].isSpace(); // true by default
+        const bool prevIsSpace = (i == 0 || text[i - 1].isSpace() || result[result.length() - 1] == zwsp);
 
         // Provide a breaking opportunity before opening parenthesis
         if (openingParens && !prevIsSpace) {
@@ -349,7 +346,10 @@ QString KStringHandler::preProcessWrap(const QString &text)
 
         result += c;
 
-        if (breakAfter && !openingParens && !nextIsSpace && !singleQuote) {
+        // Provide a breaking opportunity between camelCase and PascalCase sub-words
+        const bool isCamelCase = isLower && nextIsUpper;
+
+        if (isCamelCase || (breakAfter && !openingParens && !nextIsSpace && !singleQuote)) {
             result += zwsp;
         }
     }
@@ -361,8 +361,8 @@ int KStringHandler::logicalLength(const QString &text)
 {
     int length = 0;
     const auto chrs = text.toUcs4();
-    for (auto chr : chrs) {
-        auto script = QChar::script(chr);
+    for (const auto chr : chrs) {
+        const auto script = QChar::script(chr);
         /* clang-format off */
         if (script == QChar::Script_Han
             || script == QChar::Script_Hangul
